@@ -106,7 +106,7 @@ pub fn solve(input: &mut Input) -> Result<i32, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!(
             "1, 1
